<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Campanello in sessione &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>Sessione &apos;%1&apos; terminata con codice %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Sessione &apos;%1&apos; terminata inaspettatamente.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Sessione &apos;%1&apos; terminata inaspettatamente.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1275"/>
        <source>Size: XXX x XXX</source>
        <translation>Dimensione: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1287"/>
        <source>Size: %1 x %2</source>
        <translation>Dimensione: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2787"/>
        <source>Paste multiline text</source>
        <translation>Incolla testo multi-righe</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2788"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Si è sicuro di voler incollare questo testo?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3258"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;L&apos;output è stato &lt;a href=&quot;https://it.wikipedia.org/wiki/Controllo_di_flusso&quot;&gt;sospeso&lt;/a&gt; premendo Ctrl+S.  Premi &lt;b&gt;Ctrl+Q&lt;/b&gt; per riprendere.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nessuno traduttore di tastiera disponibile.  L&apos;informazione necessaria per convertire tasti in caratteri da inviare al terminale è mancante.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2794"/>
        <source>Show Details...</source>
        <translation>Mostra dettagli...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Schema Colore senza nome</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Schema Colore Accessibile</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Apri collegamento</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Copia indirizzo collegamento</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Invia email a...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Copia indirizzo email</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="469"/>
        <source>Color Scheme Error</source>
        <translation>Errore su Schema Colori</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="470"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Caricamento schema colore %1 non riuscito</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Rispetta maiuscolo/minuscolo</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Espressione regolare</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Evidenzia tutte le corrispondenze</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Barra di ricerca</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Trova:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
